@@ -6,7 +6,7 @@ from paco.models import loader
 from paco.models import schemas
 from paco.models.base import Parent, Named, Deployable, Regionalized, Resource, AccountRef, \
     DNSEnablable, CFNExport, md5sum
-from paco.models.exceptions import InvalidPacoBucket
+from paco.models.exceptions import InvalidPacoBucket, InvalidModelObject
 from paco.models.formatter import get_formatted_model_context, smart_join
 from paco.models.locations import get_parent_by_interface
 from paco.models.metrics import Monitorable, AlarmNotifications
@@ -259,6 +259,7 @@ class S3Bucket(Resource, Deployable):
             return self.bucket_name
 
         ne = get_parent_by_interface(self, schemas.INetworkEnvironment)
+        service = get_parent_by_interface(self, schemas.IService)
         app = get_parent_by_interface(self, schemas.IApplication)
 
 
@@ -277,7 +278,7 @@ class S3Bucket(Resource, Deployable):
         bucket_name_list = []
         # Bucket in a NetworkEnvironment contained Application
         if ne != None and app != None:
-            # NE buckets are in the format:
+            # NetworkEnvironment Application buckets are in the format:
             # ne-<netenv>-<env>-app-<app>-<resourcegroup>-<resource>-<bucket_name_prefix>-<bucketname>-<bucket_name_suffix>-<shortregionname>
             bucket_name_list.extend([
                 'ne',
@@ -288,12 +289,11 @@ class S3Bucket(Resource, Deployable):
                 get_parent_by_interface(self, schemas.IResourceGroup).name,
             ])
             bucket_name_list.extend(bucket_name_list_standard)
-        # currently only seen in Services ... ToDo: allow these names to add an additional prefix?
-        elif app != None:
-            # Application buckets are in the format:
-            # app-<app>-<resourcegroup>-<resource>-<bucket_name_prefix>-<bucketname>-<bucket_name_suffix>-<shortregionname>
+        elif service != None and app != None:
+            # Service Application buckets are in the format:
+            # service-<app>-<resourcegroup>-<resource>-<bucket_name_prefix>-<bucketname>-<bucket_name_suffix>-<shortregionname>
             bucket_name_list.extend([
-                'app',
+                'service',
                 app.name,
                 get_parent_by_interface(self, schemas.IResourceGroup).name,
             ])
@@ -462,8 +462,9 @@ class BlockDeviceMapping(Parent):
     }
 
 @implementer(schemas.IASGRollingUpdatePolicy)
-class ASGRollingUpdatePolicy(Named, Deployable):
+class ASGRollingUpdatePolicy(Named):
     title = "RollingUpdatePolicy"
+    enabled = FieldProperty(schemas.IASGRollingUpdatePolicy['enabled'])
     max_batch_size = FieldProperty(schemas.IASGRollingUpdatePolicy['max_batch_size'])
     min_instances_in_service = FieldProperty(schemas.IASGRollingUpdatePolicy['min_instances_in_service'])
     pause_time = FieldProperty(schemas.IASGRollingUpdatePolicy['pause_time'])
@@ -477,8 +478,6 @@ class ASG(Resource, Monitorable):
     desired_capacity_ignore_changes =  FieldProperty(schemas.IASG['desired_capacity_ignore_changes'])
     min_instances =  FieldProperty(schemas.IASG['min_instances'])
     max_instances =  FieldProperty(schemas.IASG['max_instances'])
-    update_policy_max_batch_size =  FieldProperty(schemas.IASG['update_policy_max_batch_size'])
-    update_policy_min_instances_in_service =  FieldProperty(schemas.IASG['update_policy_min_instances_in_service'])
     associate_public_ip_address =  FieldProperty(schemas.IASG['associate_public_ip_address'])
     cooldown_secs =  FieldProperty(schemas.IASG['cooldown_secs'])
     ebs_optimized =  FieldProperty(schemas.IASG['ebs_optimized'])
@@ -518,24 +517,41 @@ class ASG(Resource, Monitorable):
         self.load_balancers = []
         self.efs_mounts = []
         self.ebs_volume_mounts = []
+        self.rolling_update_policy = ASGRollingUpdatePolicy('rolling_update_policy', self)
 
     def get_aws_name(self):
         "AutoScalingGroup Name for AWS"
+        name_list = []
+
+        # NetworkEnvironment or Service name
         netenv = get_parent_by_interface(self, schemas.INetworkEnvironment)
+        if netenv == None:
+            service = get_parent_by_interface(self, schemas.IService)
+            if service == None:
+                raise InvalidModelObject("""Unable to find an INetworkEnvironment or IService model object.""")
+            name_list.append('Service')
+        else:
+            name_list.append(netenv.name)
+
+        # Environment name or Blank if one does not exist
         env = get_parent_by_interface(self, schemas.IEnvironment)
+        if env != None:
+            name_list.append(env.name)
+
+        # Application Name
         app = get_parent_by_interface(self, schemas.IApplication)
         resource_group = get_parent_by_interface(self, schemas.IResourceGroup)
-        return self.create_resource_name_join(
-                name_list=[
-                    netenv.name,
-                    env.name,
-                    app.name,
-                    resource_group.name,
-                    self.name
-                ],
+        name_list.extend([
+            app.name,
+            resource_group.name,
+            self.name
+        ])
+        aws_name = self.create_resource_name_join(
+                name_list=name_list,
                 separator='-',
                 camel_case=True
         )
+        return aws_name
 
     def resolve_ref(self, ref):
         if ref.resource_ref == 'name':
@@ -601,6 +617,7 @@ class Listeners(Named, dict):
 class Listener(Named, PortProtocol):
     redirect = FieldProperty(schemas.IListener['redirect'])
     ssl_certificates = FieldProperty(schemas.IListener['ssl_certificates'])
+    ssl_policy = FieldProperty(schemas.IListener['ssl_policy'])
     target_group = FieldProperty(schemas.IListener['target_group'])
     rules = FieldProperty(schemas.IListener['rules'])
 
@@ -611,7 +628,7 @@ class Listener(Named, PortProtocol):
         # 'LoadBalancerArn': (basestring, True),
         'Port': 'port',
         'Protocol': 'protocol',
-        # 'SslPolicy': (basestring, False)
+        # 'SslPolicy': computed in template
     }
 
 @implementer(schemas.IDNS)
@@ -1186,7 +1203,7 @@ class DeploymentPipelineSourceGitHub(DeploymentPipelineStageAction):
     deployment_branch_name = FieldProperty(schemas.IDeploymentPipelineSourceGitHub['deployment_branch_name'])
     github_owner = FieldProperty(schemas.IDeploymentPipelineSourceGitHub['github_owner'])
     github_repository = FieldProperty(schemas.IDeploymentPipelineSourceGitHub['github_repository'])
-    github_token_parameter_name = FieldProperty(schemas.IDeploymentPipelineSourceGitHub['github_token_parameter_name'])
+    github_access_token = FieldProperty(schemas.IDeploymentPipelineSourceGitHub['github_access_token'])
 
 @implementer(schemas.IDeploymentPipelineBuildCodeBuild)
 class DeploymentPipelineBuildCodeBuild(DeploymentPipelineStageAction):
