@@ -81,6 +81,12 @@ class Testpacodemo(BaseTestModelLoader):
         demo_env = self.project['netenv']['pacodemo']['demo']['us-west-2']
         asg = demo_env.applications['app'].groups['site'].resources['webapp']
 
+        # rolling_udpate_policy
+        assert asg.rolling_update_policy.max_batch_size == 1
+        assert asg.rolling_update_policy.min_instances_in_service == 0
+        assert asg.rolling_update_policy.pause_time == 'PT1M'
+        assert asg.rolling_update_policy.wait_on_resource_signals == False
+
         # CloudFormation Init
         cfn_init = asg.cfn_init
         assert schemas.ICloudFormationInit.providedBy(cfn_init)
@@ -365,3 +371,28 @@ class Testpacodemo(BaseTestModelLoader):
         assert schemas.ICloudWatchDashboard.providedBy(dashboard)
         assert dashboard.title == "Demo-Dashboard"
         assert 'WebAsg.name' in dashboard.variables
+
+    def test_iotcore(self):
+        demo_env = self.project['netenv']['pacodemo']['demo']['us-west-2']
+        iottopic = demo_env['applications']['app'].groups['iot'].resources['iottopic']
+        assert schemas.IIoTTopicRule.providedBy(iottopic)
+        assert iottopic.sql == "SELECT * FROM 'iot/myTestTopic'"
+
+        iotpolicy = demo_env['applications']['app'].groups['iot'].resources['iotpolicy']
+        assert schemas.IIoTPolicy.providedBy(iotpolicy)
+        assert iotpolicy.variables['sensor_topic_arn'].startswith('paco.ref ')
+
+    def test_iotanalyticspipeline(self):
+        demo_env = self.project['netenv']['pacodemo']['demo']['us-west-2']
+        iotpipeline = demo_env['applications']['app'].groups['iot'].resources['raw_analysis']
+        assert schemas.IIoTAnalyticsPipeline.providedBy(iotpipeline)
+        assert iotpipeline.channel_storage.key_prefix == 'raw_input/'
+        assert iotpipeline.datastore_storage.expire_events_after_days == 30
+        assert iotpipeline.pipeline_activities['extra_bit'].attributes['key1'] == 'heyguy'
+
+        # datasets
+        sample = iotpipeline.datasets['sample']
+        assert sample.query_action.sql_query == "SELECT * FROM example"
+        assert sample.content_delivery_rules['s3dump'].s3_destination.key == "/DataSet/!{iotanalytics:scheduleTime}/!{iotanalytics:versionId}.csv"
+        assert sample.version_history == 2
+        assert sample.expire_events_after_days == 3
